/*
 * Folder identifier functions
 *
 * Copyright (c) 2010-2014, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <common.h>
#include <memory.h>
#include <types.h>

#include "libfwsi_definitions.h"
#include "libfwsi_folder_identifier.h"
#include "libfwsi_libcerror.h"

uint8_t libfwsi_folder_identifier_common_files[ 16 ] = \
	{ 0x24, 0x4d, 0x97, 0xde, 0xc6, 0xd9, 0x3e, 0x4d, 0xbf, 0x91, 0xf4, 0x45, 0x51, 0x20, 0xb9, 0x17 };

uint8_t libfwsi_folder_identifier_computer_and_devices[ 16 ] = \
	{ 0x0d, 0x1a, 0x2c, 0xf0, 0x21, 0xbe, 0x50, 0x43, 0x88, 0xb0, 0x73, 0x67, 0xfc, 0x96, 0xef, 0x3c };

uint8_t libfwsi_folder_identifier_control_panel[ 16 ] = \
	{ 0x20, 0x20, 0xec, 0x21, 0xea, 0x3a, 0x69, 0x10, 0xa2, 0xdd, 0x08, 0x00, 0x2b, 0x30, 0x30, 0x9d };

uint8_t libfwsi_folder_identifier_control_panel_desktop[ 16 ] = \
	{ 0x94, 0xe6, 0x99, 0x53, 0xe5, 0x6c, 0x6c, 0x4d, 0x8f, 0xce, 0x1d, 0x88, 0x70, 0xfd, 0xcb, 0xa0 };

uint8_t libfwsi_folder_identifier_control_panel_vista[ 16 ] = \
	{ 0x68, 0x06, 0xee, 0x26, 0x0a, 0xa0, 0xd7, 0x44, 0x93, 0x71, 0xbe, 0xb0, 0x64, 0xc9, 0x86, 0x83 };

uint8_t libfwsi_folder_identifier_documents[ 16 ] = \
	{ 0xd0, 0x9a, 0xd3, 0xfd, 0x8f, 0x23, 0xaf, 0x46, 0xad, 0xb4, 0x6c, 0x85, 0x48, 0x03, 0x69, 0xc7 };

uint8_t libfwsi_folder_identifier_downloads[ 16 ] = \
	{ 0x90, 0xe2, 0x4d, 0x37, 0x3f, 0x12, 0x65, 0x45, 0x91, 0x64, 0x39, 0xc4, 0x92, 0x5e, 0x46, 0x7b };

uint8_t libfwsi_folder_identifier_files_user[ 16 ] = \
	{ 0x7c, 0x0f, 0xce, 0xf3, 0x01, 0x49, 0xcc, 0x4a, 0x86, 0x48, 0xd5, 0xd4, 0x4b, 0x04, 0xef, 0x8f };

uint8_t libfwsi_folder_identifier_internet_explorer[ 16 ] = \
	{ 0x80, 0x53, 0x1c, 0x87, 0xa0, 0x42, 0x69, 0x10, 0xa2, 0xea, 0x08, 0x00, 0x2b, 0x30, 0x30, 0x9d };

uint8_t libfwsi_folder_identifier_library_documents[ 16 ] = \
	{ 0x7d, 0xb1, 0x0d, 0x7b, 0xd2, 0x9c, 0x93, 0x4a, 0x97, 0x33, 0x46, 0xcc, 0x89, 0x02, 0x2e, 0x7c };

uint8_t libfwsi_folder_identifier_music[ 16 ] = \
	{ 0x71, 0xd5, 0xd8, 0x4b, 0x19, 0x6d, 0xd3, 0x48, 0xbe, 0x97, 0x42, 0x22, 0x20, 0x08, 0x0e, 0x43 };

uint8_t libfwsi_folder_identifier_my_computer[ 16 ] = \
	{ 0xe0, 0x4f, 0xd0, 0x20, 0xea, 0x3a, 0x69, 0x10, 0xa2, 0xd8, 0x08, 0x00, 0x2b, 0x30, 0x30, 0x9d };

uint8_t libfwsi_folder_identifier_my_documents[ 16 ] = \
	{ 0xba, 0x8f, 0x0d, 0x45, 0x25, 0xad, 0xd0, 0x11, 0x98, 0xa8, 0x08, 0x00, 0x36, 0x1b, 0x11, 0x03 };

uint8_t libfwsi_folder_identifier_my_games[ 16 ] = \
	{ 0xdf, 0x8f, 0x22, 0xed, 0xa8, 0x9e ,0x70, 0x48, 0x83, 0xb1, 0x96, 0xb0, 0x2c, 0xfe, 0x0d, 0x52 };

uint8_t libfwsi_folder_identifier_my_network_places[ 16 ] = \
	{ 0x60, 0x2c, 0x8d, 0x20, 0xea, 0x3a, 0x69, 0x10, 0xa2, 0xd7, 0x08, 0x00, 0x2b, 0x30, 0x30, 0x9d };

uint8_t libfwsi_folder_identifier_network_and_sharing_center[ 16 ] = \
	{ 0xc9, 0x8f, 0x90, 0x8e, 0xcc, 0xbe, 0xf6, 0x40, 0x91, 0x5b, 0xf4, 0xca, 0x0e, 0x70, 0xd0, 0x3d };

uint8_t libfwsi_folder_identifier_parential_controls[ 16 ] = \
	{ 0x84, 0x8d, 0xae, 0x96, 0x50, 0xa2, 0x20, 0x45, 0x95, 0xa5, 0xa4, 0x7a, 0x7e, 0x3c, 0x54, 0x8b };

uint8_t libfwsi_folder_identifier_pictures[ 16 ] = \
	{ 0x30, 0x81, 0xe2, 0x33, 0x1e, 0x4e, 0x76, 0x46, 0x83, 0x5a, 0x98, 0x39, 0x5c, 0x3b, 0xc3, 0xbb };

uint8_t libfwsi_folder_identifier_program_files[ 16 ] = \
	{ 0xb6, 0x63, 0x5e, 0x90, 0xbf, 0xc1, 0x4e, 0x49, 0xb2, 0x9c, 0x65, 0xb7, 0x32, 0xd3, 0xd2, 0x1a };

uint8_t libfwsi_folder_identifier_program_files_x86[ 16 ] = \
	{ 0xef, 0x40, 0x5a, 0x7c, 0xfb, 0xa0, 0xfc, 0x4b, 0x87, 0x4a, 0xc0, 0xf2, 0xe0, 0xb9, 0xfa, 0x8e };

uint8_t libfwsi_folder_identifier_programs_and_features[ 16 ] = \
	{ 0x6a, 0xbe, 0x81, 0x7b, 0x2b, 0xce, 0x76, 0x46, 0xa2, 0x9e, 0xeb, 0x90, 0x7a, 0x51, 0x26, 0xc5 };

uint8_t libfwsi_folder_identifier_public[ 16 ] = \
	{ 0xa2, 0x76, 0xdf, 0xdf, 0x2a, 0xc8, 0x63, 0x4d, 0x90, 0x6a, 0x56, 0x44, 0xac, 0x45, 0x73, 0x85 };

uint8_t libfwsi_folder_identifier_public_music[ 16 ] = \
	{ 0xb5, 0xfa, 0x14, 0x32, 0x57, 0x97, 0x98, 0x42, 0xbb, 0x61, 0x92, 0xa9, 0xde, 0xaa, 0x44, 0xff };

uint8_t libfwsi_folder_identifier_public_pictures[ 16 ] = \
	{ 0x86, 0xfb, 0xeb, 0xb6, 0x07, 0x69, 0x3c, 0x41, 0x9a, 0xf7, 0x4f, 0xc2, 0xab, 0xf0, 0x7c, 0xc5 };

uint8_t libfwsi_folder_identifier_public_videos[ 16 ] = \
	{ 0x3a, 0x18, 0x00, 0x24, 0x85, 0x61, 0xfb, 0x49, 0xa2, 0xd8, 0x4a, 0x39, 0x2a, 0x60, 0x2b, 0xa3 };

uint8_t libfwsi_folder_identifier_recycle_bin[ 16 ] = \
	{ 0x40, 0xf0, 0x5f, 0x64, 0x81, 0x50, 0x1b, 0x10, 0x9f, 0x08, 0x00, 0xaa, 0x00, 0x2f, 0x95, 0x4e };

uint8_t libfwsi_folder_identifier_search_home[ 16 ] = \
	{ 0x2e, 0x81, 0x43, 0x93, 0x37, 0x1c, 0x49, 0x4a, 0xa1, 0x2e, 0x4b, 0x2d, 0x81, 0x0d, 0x95, 0x6b };

uint8_t libfwsi_folder_identifier_system[ 16 ] = \
	{ 0x77, 0x4e, 0xc1, 0x1a, 0xe7, 0x02, 0x5d, 0x4e, 0xb7, 0x44, 0x2e, 0xb1, 0xae, 0x51, 0x98, 0xb7 };

uint8_t libfwsi_folder_identifier_system32_x86[ 16 ] = \
	{ 0xb0, 0x31, 0x52, 0xd6, 0xf1, 0xb2, 0x57, 0x48, 0xa4, 0xce, 0xa8, 0xe7, 0xc6, 0xea, 0x7d, 0x27 };

uint8_t libfwsi_folder_identifier_taskbar[ 16 ] = \
	{ 0xf4, 0xb0, 0xd7, 0x05, 0x21, 0x21, 0xff, 0x4e, 0xbf, 0x6b, 0xed, 0x3f, 0x69, 0xb8, 0x94, 0xd9 };

uint8_t libfwsi_folder_identifier_users[ 16 ] = \
	{ 0x47, 0x1a, 0x03, 0x59, 0x72, 0x3f, 0xa7, 0x44, 0x89, 0xc5, 0x55, 0x95, 0xfe, 0x6b, 0x30, 0xee };

uint8_t libfwsi_folder_identifier_users_libraries[ 16 ] = \
	{ 0x25, 0x48, 0x1e, 0x03, 0x94, 0x7b, 0xc3, 0x4d, 0xb1, 0x31, 0xe9, 0x46, 0xb4, 0x4c, 0x8d, 0xd5 };

uint8_t libfwsi_folder_identifier_window_switcher[ 16 ] = \
	{ 0x0e, 0xf9, 0x80, 0x30, 0xad, 0xd7, 0xd9, 0x11, 0xbd, 0x98, 0x00, 0x00, 0x94, 0x7b, 0x02, 0x57 };

uint8_t libfwsi_folder_identifier_windows[ 16 ] = \
	{ 0x04, 0xf4, 0x8b, 0xf3, 0x43, 0x1d, 0xf2, 0x42, 0x93, 0x05, 0x67, 0xde, 0x0b, 0x28, 0xfc, 0x23 };

uint8_t libfwsi_folder_identifier_unknown[ 16 ] = \
	{ 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };

/* Unknown

Found in Program Compatibility Wizard.lnk and Windows Catalog.lnk
Found in Sample Music.lnk
uint8_t libfwsi_folder_identifier_unknown[ 16 ] = \
	{ 0x4d, 0xa5, 0x36, 0x43, 0x8b, 0x03, 0x85, 0x46, 0xab, 0x02, 0x99, 0xbb, 0x52, 0xd3, 0xfb, 0x8b };
*/

/* The folder identifiers
 */
libfwsi_folder_identifier_definition_t libfwsi_folder_identifier_definitions[ ] = {
	{ libfwsi_folder_identifier_common_files,		"Common Files" },
	{ libfwsi_folder_identifier_computer_and_devices,	"Computer and Devices" },
	{ libfwsi_folder_identifier_control_panel,		"Control Panel" },
	{ libfwsi_folder_identifier_control_panel_desktop,	"Control Panel (Desktop and Start Menu)" },
	{ libfwsi_folder_identifier_control_panel_vista,	"Control Panel" },
	{ libfwsi_folder_identifier_documents,			"Documents" },
	{ libfwsi_folder_identifier_downloads,			"Downloads" },
	{ libfwsi_folder_identifier_files_user,			"User's Files" },
	{ libfwsi_folder_identifier_internet_explorer,		"Internet Explorer (Homepage)" },
	{ libfwsi_folder_identifier_library_documents,		"Documents (Library)" },
	{ libfwsi_folder_identifier_music,			"Music" },
	{ libfwsi_folder_identifier_my_computer,		"My Computer" },
	{ libfwsi_folder_identifier_my_documents,		"My Documents" },
	{ libfwsi_folder_identifier_my_games,			"My Games" },
	{ libfwsi_folder_identifier_my_network_places,		"My Network Places" },
	{ libfwsi_folder_identifier_network_and_sharing_center,	"Network and Sharing Center" },
	{ libfwsi_folder_identifier_parential_controls,		"Parential Controls" },
	{ libfwsi_folder_identifier_pictures,			"Pictures" },
	{ libfwsi_folder_identifier_program_files,		"Program Files" },
	{ libfwsi_folder_identifier_program_files_x86,		"Program Files (x86)" },
	{ libfwsi_folder_identifier_programs_and_features,	"Programs and Features" },
	{ libfwsi_folder_identifier_public,			"Public" },
	{ libfwsi_folder_identifier_public_music,		"Public Music" },
	{ libfwsi_folder_identifier_public_pictures,		"Public Pictures" },
	{ libfwsi_folder_identifier_public_videos,		"Public Videos" },
	{ libfwsi_folder_identifier_recycle_bin,		"Recycle Bin" },
	{ libfwsi_folder_identifier_search_home,		"Search Home" },
	{ libfwsi_folder_identifier_system,			"System" },
	{ libfwsi_folder_identifier_system32_x86,		"System32 (x86)" },
	{ libfwsi_folder_identifier_taskbar,			"Taskbar" },
	{ libfwsi_folder_identifier_users,			"Users" },
	{ libfwsi_folder_identifier_users_libraries,		"Users Libraries" },
	{ libfwsi_folder_identifier_window_switcher,		"Window Switcher" },
	{ libfwsi_folder_identifier_windows,			"Windows" },

	{ libfwsi_folder_identifier_unknown,			"Unknown" } };

/* Retrieves a string containing the name of the folder identifier
 */
const char *libfwsi_folder_identifier_get_name(
             const uint8_t *folder_identifier )
{
	int iterator = 0;

	if( folder_identifier == NULL )
	{
		return( "Invalid folder identifier" );
	}
	while( memory_compare(
	        ( libfwsi_folder_identifier_definitions[ iterator ] ).identifier,
	        libfwsi_folder_identifier_unknown,
	        16 ) != 0 )
	{
		if( memory_compare(
		     ( libfwsi_folder_identifier_definitions[ iterator ] ).identifier,
		     folder_identifier,
		     16 ) == 0 )
		{
			break;
		}
		iterator++;
	}
	return(
	 ( libfwsi_folder_identifier_definitions[ iterator ] ).name );
}

