/*
 * Folder identifier functions
 *
 * Copyright (c) 2010-2014, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#if !defined( _LIBFMAPI_CLASS_IDENTIFIER_H )
#define _LIBFMAPI_CLASS_IDENTIFIER_H

#include <common.h>
#include <types.h>

#include "libfwsi_definitions.h"
#include "libfwsi_extern.h"
#include "libfwsi_libcerror.h"

#if defined( __cplusplus )
extern "C" {
#endif

/* The CLSID is stored as a little endian GUID
 */
typedef struct libfwsi_folder_identifier_definition libfwsi_folder_identifier_definition_t;

struct libfwsi_folder_identifier_definition
{
	/* The folder identifier
	 */
	uint8_t *identifier;

	/* The folder name
	 */
	const char *name;
};

extern uint8_t libfwsi_folder_identifier_common_files[ 16 ];
extern uint8_t libfwsi_folder_identifier_computer_and_devices[ 16 ];
extern uint8_t libfwsi_folder_identifier_control_panel[ 16 ];
extern uint8_t libfwsi_folder_identifier_control_panel_desktop[ 16 ];
extern uint8_t libfwsi_folder_identifier_control_panel_vista[ 16 ];
extern uint8_t libfwsi_folder_identifier_documents[ 16 ];
extern uint8_t libfwsi_folder_identifier_downloads[ 16 ];
extern uint8_t libfwsi_folder_identifier_files_user[ 16 ];
extern uint8_t libfwsi_folder_identifier_internet_explorer[ 16 ];
extern uint8_t libfwsi_folder_identifier_library_documents[ 16 ];
extern uint8_t libfwsi_folder_identifier_music[ 16 ];
extern uint8_t libfwsi_folder_identifier_music_public[ 16 ];
extern uint8_t libfwsi_folder_identifier_my_computer[ 16 ];
extern uint8_t libfwsi_folder_identifier_my_documents[ 16 ];
extern uint8_t libfwsi_folder_identifier_my_games[ 16 ];
extern uint8_t libfwsi_folder_identifier_my_network_places[ 16 ];
extern uint8_t libfwsi_folder_identifier_network_and_sharing_center[ 16 ];
extern uint8_t libfwsi_folder_identifier_parential_controls[ 16 ];
extern uint8_t libfwsi_folder_identifier_pictures[ 16 ];
extern uint8_t libfwsi_folder_identifier_program_files[ 16 ];
extern uint8_t libfwsi_folder_identifier_program_files_x86[ 16 ];
extern uint8_t libfwsi_folder_identifier_programs_and_features[ 16 ];
extern uint8_t libfwsi_folder_identifier_public[ 16 ];
extern uint8_t libfwsi_folder_identifier_public_pictures[ 16 ];
extern uint8_t libfwsi_folder_identifier_public_videos[ 16 ];
extern uint8_t libfwsi_folder_identifier_recycle_bin[ 16 ];
extern uint8_t libfwsi_folder_identifier_search_home[ 16 ];
extern uint8_t libfwsi_folder_identifier_system[ 16 ];
extern uint8_t libfwsi_folder_identifier_system32_x86[ 16 ];
extern uint8_t libfwsi_folder_identifier_taskbar[ 16 ];
extern uint8_t libfwsi_folder_identifier_users[ 16 ];
extern uint8_t libfwsi_folder_identifier_users_libraries[ 16 ];
extern uint8_t libfwsi_folder_identifier_window_switcher[ 16 ];
extern uint8_t libfwsi_folder_identifier_windows[ 16 ];
extern uint8_t libfwsi_folder_identifier_unknown[ 16 ];

LIBFWSI_EXTERN \
const char *libfwsi_folder_identifier_get_name(
             const uint8_t *folder_identifier );

#if defined( __cplusplus )
}
#endif

#endif

