/*
 * Windows Shell Item functions
 *
 * Copyright (c) 2010-2014, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#if !defined( _LIBFWSI_INTERNAL_ITEM_H )
#define _LIBFWSI_INTERNAL_ITEM_H

#include <common.h>
#include <types.h>

#include "libfwsi_extern.h"
#include "libfwsi_libcerror.h"
#include "libfwsi_types.h"

#if defined( __cplusplus )
extern "C" {
#endif

typedef struct libfwsi_internal_item libfwsi_internal_item_t;

struct libfwsi_internal_item
{
	/* The type
	 */
	uint8_t type;

	/* The size
	 */
	uint16_t size;

	/* The item value
	 */
        intptr_t *value;

	/* The item free value function
	 */
	int (*free_value)(
	       intptr_t **value,
	       libcerror_error_t **error );
};

LIBFWSI_EXTERN \
int libfwsi_item_initialize(
     libfwsi_item_t **item,
     libcerror_error_t **error );

LIBFWSI_EXTERN \
int libfwsi_item_free(
     libfwsi_item_t **item,
     libcerror_error_t **error );

int libfwsi_internal_item_free(
     libfwsi_internal_item_t **internal_item,
     libcerror_error_t **error );

LIBFWSI_EXTERN \
int libfwsi_item_copy_from_byte_stream(
     libfwsi_item_t *item,
     const uint8_t *byte_stream,
     size_t byte_stream_size,
     int ascii_codepage,
     libcerror_error_t **error );

LIBFWSI_EXTERN \
int libfwsi_item_get_type(
     libfwsi_item_t *item,
     uint8_t *item_type,
     libcerror_error_t **error );

#if defined( __cplusplus )
}
#endif

#endif

